# -*- coding: utf-8 -*-
from setuptools import setup

setup(
    name="chair",
    version="1.0.0",
    author="Hakan Vergil",
    author_email='hakanvergil@gmail.com',
    url="https://pypi.org/project/chair/",
    download_url=None,
    description="Additional features for Android",
    long_description=None,
    license="MIT",
    install_requires=None,
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3"
    ],
)
